Push a local PGN file to its mapped Lichess study.

Run: chess-self-coach push $ARGUMENTS

If no file specified, ask which file from the pgn/ directory.
After pushing, provide the Lichess study URL.
Remind the user to check Chessdriller for sync.
